@@ -11,7 +11,7 @@
 #define BOTAN_ECC_DOMAIN_PARAMETERS_H_
 
 #include <botan/point_gfp.h>
-#include <botan/asn1_obj.h>
+#include <botan/asn1_oid.h>
 #include <memory>
 #include <set>
 
@@ -26,11 +26,6 @@ enum EC_Group_Encoding {
    EC_DOMPAR_ENC_OID = 2
 };
 
-enum class EC_Group_Source {
-   Builtin,
-   ExternalSource,
-};
-
 class CurveGFp;
 
 class EC_Group_Data;
@@ -88,14 +83,9 @@ class BOTAN_PUBLIC_API(2,0) EC_Group final
 
       /**
       * Decode a BER encoded ECC domain parameter set
-      * @param ber the bytes of the BER encoding
-      * @param ber_len the length of ber
+      * @param ber_encoding the bytes of the BER encoding
       */
-      explicit EC_Group(const uint8_t ber[], size_t ber_len);
-
-      template<typename Alloc>
-         EC_Group(const std::vector<uint8_t, Alloc>& ber) :
-         EC_Group(ber.data(), ber.size()) {}
+      explicit EC_Group(const std::vector<uint8_t>& ber_encoding);
 
       /**
       * Create an EC domain by OID (or throw if unknown)
@@ -107,14 +97,9 @@ class BOTAN_PUBLIC_API(2,0) EC_Group final
       * Create an EC domain from PEM encoding (as from PEM_encode), or
       * from an OID name (eg "secp256r1", or "1.2.840.10045.3.1.7")
       * @param pem_or_oid PEM-encoded data, or an OID
-
-      * @warning Support for PEM in this function is deprecated. Use
-      * EC_Group_from_PEM
       */
       explicit EC_Group(const std::string& pem_or_oid);
 
-      static EC_Group EC_Group_from_PEM(const std::string& pem);
-
       /**
       * Create an uninitialized EC_Group
       */
@@ -122,12 +107,6 @@ class BOTAN_PUBLIC_API(2,0) EC_Group final
 
       ~EC_Group();
 
-      EC_Group(const EC_Group&) = default;
-      EC_Group(EC_Group&&) = default;
-
-      EC_Group& operator=(const EC_Group&) = default;
-      EC_Group& operator=(EC_Group&&) = default;
-
       /**
       * Create the DER encoding of this domain
       * @param form of encoding to use
@@ -152,11 +131,6 @@ class BOTAN_PUBLIC_API(2,0) EC_Group final
       */
       bool a_is_minus_3() const;
 
-      /**
-      * Return if a == 0 mod p
-      */
-      bool a_is_zero() const;
-
       /**
       * Return the size of p in bits (same as get_p().bits())
       */
@@ -219,26 +193,11 @@ class BOTAN_PUBLIC_API(2,0) EC_Group final
       */
       BigInt mod_order(const BigInt& x) const;
 
-      /*
-      * Return inverse of x modulo the order
-      */
-      BigInt inverse_mod_order(const BigInt& x) const;
-
-      /*
-      * Reduce (x*x) modulo the order
-      */
-      BigInt square_mod_order(const BigInt& x) const;
-
       /*
       * Reduce (x*y) modulo the order
       */
       BigInt multiply_mod_order(const BigInt& x, const BigInt& y) const;
 
-      /*
-      * Reduce (x*y*z) modulo the order
-      */
-      BigInt multiply_mod_order(const BigInt& x, const BigInt& y, const BigInt& z) const;
-
       /**
       * Return the cofactor
       * @result the cofactor
@@ -257,7 +216,7 @@ class BOTAN_PUBLIC_API(2,0) EC_Group final
       * Return the OID of these domain parameters
       * @result the OID as a string
       */
-      std::string BOTAN_DEPRECATED("Use get_curve_oid") get_oid() const { return get_curve_oid().to_string(); }
+      std::string BOTAN_DEPRECATED("Use get_curve_oid") get_oid() const { return get_curve_oid().as_string(); }
 
       /**
       * Return the OID of these domain parameters
@@ -323,8 +282,6 @@ class BOTAN_PUBLIC_API(2,0) EC_Group final
       */
       PointGFp zero_point() const;
 
-      size_t point_size(PointGFp::Compression_Type format) const;
-
       PointGFp OS2ECP(const uint8_t bits[], size_t len) const;
 
       template<typename Alloc>
@@ -344,8 +301,6 @@ class BOTAN_PUBLIC_API(2,0) EC_Group final
 
       bool operator==(const EC_Group& other) const;
 
-      EC_Group_Source source() const;
-
       /**
       * Return PEM representation of named EC group
       * Deprecated: Use EC_Group(name).PEM_encode() if this is needed
@@ -367,8 +322,7 @@ class BOTAN_PUBLIC_API(2,0) EC_Group final
    private:
       static EC_Group_Data_Map& ec_group_data();
 
-      static std::shared_ptr<EC_Group_Data> BER_decode_EC_group(const uint8_t bits[], size_t len,
-                                                                EC_Group_Source source);
+      static std::shared_ptr<EC_Group_Data> BER_decode_EC_group(const uint8_t bits[], size_t len);
 
       static std::shared_ptr<EC_Group_Data>
          load_EC_group_info(const char* p,
